summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoe Gordon <joe.gordon0@gmail.com>2015-01-27 12:59:15 -0800
committerJoe Gordon <joe.gordon0@gmail.com>2015-01-27 13:06:06 -0800
commit3561772f8b0cfee746af53fa228375b2ec7dfd9d (patch)
treedb17dcd13f893639354b48b9288cbbd407d56b0b
parent7544dcb4ea92247c1e8fa97b8f0aba566e33ca48 (diff)
downloadpython-novaclient-3561772f8b0cfee746af53fa228375b2ec7dfd9d.tar.gz
Move unit tests into unit test directory
In order to pave the way for functional testing, move existing unit tests into a directory labeled unit. A subsequent patch will add a directory for functional tests. Change-Id: I0adb8b9f14451acb382c725d31f5387b4b6d82bb
-rw-r--r--novaclient/tests/unit/__init__.py (renamed from novaclient/tests/fixture_data/__init__.py)0
-rw-r--r--novaclient/tests/unit/fakes.py (renamed from novaclient/tests/fakes.py)0
-rw-r--r--novaclient/tests/unit/fixture_data/__init__.py (renamed from novaclient/tests/v1_1/__init__.py)0
-rw-r--r--novaclient/tests/unit/fixture_data/agents.py (renamed from novaclient/tests/fixture_data/agents.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/aggregates.py (renamed from novaclient/tests/fixture_data/aggregates.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/availability_zones.py (renamed from novaclient/tests/fixture_data/availability_zones.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/base.py (renamed from novaclient/tests/fixture_data/base.py)0
-rw-r--r--novaclient/tests/unit/fixture_data/certs.py (renamed from novaclient/tests/fixture_data/certs.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/client.py (renamed from novaclient/tests/fixture_data/client.py)0
-rw-r--r--novaclient/tests/unit/fixture_data/cloudpipe.py (renamed from novaclient/tests/fixture_data/cloudpipe.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/fixedips.py (renamed from novaclient/tests/fixture_data/fixedips.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/floatingips.py (renamed from novaclient/tests/fixture_data/floatingips.py)4
-rw-r--r--novaclient/tests/unit/fixture_data/fping.py (renamed from novaclient/tests/fixture_data/fping.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/hosts.py (renamed from novaclient/tests/fixture_data/hosts.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/hypervisors.py (renamed from novaclient/tests/fixture_data/hypervisors.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/images.py (renamed from novaclient/tests/fixture_data/images.py)4
-rw-r--r--novaclient/tests/unit/fixture_data/keypairs.py (renamed from novaclient/tests/fixture_data/keypairs.py)4
-rw-r--r--novaclient/tests/unit/fixture_data/limits.py (renamed from novaclient/tests/fixture_data/limits.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/networks.py (renamed from novaclient/tests/fixture_data/networks.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/quotas.py (renamed from novaclient/tests/fixture_data/quotas.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/security_group_rules.py (renamed from novaclient/tests/fixture_data/security_group_rules.py)4
-rw-r--r--novaclient/tests/unit/fixture_data/security_groups.py (renamed from novaclient/tests/fixture_data/security_groups.py)4
-rw-r--r--novaclient/tests/unit/fixture_data/server_groups.py (renamed from novaclient/tests/fixture_data/server_groups.py)2
-rw-r--r--novaclient/tests/unit/fixture_data/servers.py (renamed from novaclient/tests/fixture_data/servers.py)6
-rw-r--r--novaclient/tests/unit/idfake.pem (renamed from novaclient/tests/idfake.pem)0
-rw-r--r--novaclient/tests/unit/test_auth_plugins.py (renamed from novaclient/tests/test_auth_plugins.py)2
-rw-r--r--novaclient/tests/unit/test_base.py (renamed from novaclient/tests/test_base.py)4
-rw-r--r--novaclient/tests/unit/test_client.py (renamed from novaclient/tests/test_client.py)2
-rw-r--r--novaclient/tests/unit/test_discover.py (renamed from novaclient/tests/test_discover.py)2
-rw-r--r--novaclient/tests/unit/test_http.py (renamed from novaclient/tests/test_http.py)2
-rw-r--r--novaclient/tests/unit/test_service_catalog.py (renamed from novaclient/tests/test_service_catalog.py)2
-rw-r--r--novaclient/tests/unit/test_shell.py (renamed from novaclient/tests/test_shell.py)2
-rw-r--r--novaclient/tests/unit/test_utils.py (renamed from novaclient/tests/test_utils.py)2
-rw-r--r--novaclient/tests/unit/utils.py (renamed from novaclient/tests/utils.py)0
-rw-r--r--novaclient/tests/unit/v1_1/__init__.py (renamed from novaclient/tests/v1_1/contrib/__init__.py)0
-rw-r--r--novaclient/tests/unit/v1_1/contrib/__init__.py0
-rw-r--r--novaclient/tests/unit/v1_1/contrib/fakes.py (renamed from novaclient/tests/v1_1/contrib/fakes.py)2
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_assisted_volume_snapshots.py (renamed from novaclient/tests/v1_1/contrib/test_assisted_volume_snapshots.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_baremetal.py (renamed from novaclient/tests/v1_1/contrib/test_baremetal.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_cells.py (renamed from novaclient/tests/v1_1/contrib/test_cells.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_instance_actions.py (renamed from novaclient/tests/v1_1/contrib/test_instance_actions.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_list_extensions.py (renamed from novaclient/tests/v1_1/contrib/test_list_extensions.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_migrations.py (renamed from novaclient/tests/v1_1/contrib/test_migrations.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_server_external_events.py (renamed from novaclient/tests/v1_1/contrib/test_server_external_events.py)4
-rw-r--r--novaclient/tests/unit/v1_1/contrib/test_tenant_networks.py (renamed from novaclient/tests/v1_1/contrib/test_tenant_networks.py)4
-rw-r--r--novaclient/tests/unit/v1_1/fakes.py (renamed from novaclient/tests/v1_1/fakes.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_agents.py (renamed from novaclient/tests/v1_1/test_agents.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_aggregates.py (renamed from novaclient/tests/v1_1/test_aggregates.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_auth.py (renamed from novaclient/tests/v1_1/test_auth.py)2
-rw-r--r--novaclient/tests/unit/v1_1/test_availability_zone.py (renamed from novaclient/tests/v1_1/test_availability_zone.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_certs.py (renamed from novaclient/tests/v1_1/test_certs.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_client.py (renamed from novaclient/tests/v1_1/test_client.py)2
-rw-r--r--novaclient/tests/unit/v1_1/test_cloudpipe.py (renamed from novaclient/tests/v1_1/test_cloudpipe.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_fixed_ips.py (renamed from novaclient/tests/v1_1/test_fixed_ips.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_flavor_access.py (renamed from novaclient/tests/v1_1/test_flavor_access.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_flavors.py (renamed from novaclient/tests/v1_1/test_flavors.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_floating_ip_dns.py (renamed from novaclient/tests/v1_1/test_floating_ip_dns.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_floating_ip_pools.py (renamed from novaclient/tests/v1_1/test_floating_ip_pools.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_floating_ips.py (renamed from novaclient/tests/v1_1/test_floating_ips.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_floating_ips_bulk.py (renamed from novaclient/tests/v1_1/test_floating_ips_bulk.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_fping.py (renamed from novaclient/tests/v1_1/test_fping.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_hosts.py (renamed from novaclient/tests/v1_1/test_hosts.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_hypervisors.py (renamed from novaclient/tests/v1_1/test_hypervisors.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_images.py (renamed from novaclient/tests/v1_1/test_images.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_keypairs.py (renamed from novaclient/tests/v1_1/test_keypairs.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_limits.py (renamed from novaclient/tests/v1_1/test_limits.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_networks.py (renamed from novaclient/tests/v1_1/test_networks.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_quota_classes.py (renamed from novaclient/tests/v1_1/test_quota_classes.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_quotas.py (renamed from novaclient/tests/v1_1/test_quotas.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_security_group_rules.py (renamed from novaclient/tests/v1_1/test_security_group_rules.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_security_groups.py (renamed from novaclient/tests/v1_1/test_security_groups.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_server_groups.py (renamed from novaclient/tests/v1_1/test_server_groups.py)6
-rw-r--r--novaclient/tests/unit/v1_1/test_servers.py (renamed from novaclient/tests/v1_1/test_servers.py)12
-rw-r--r--novaclient/tests/unit/v1_1/test_services.py (renamed from novaclient/tests/v1_1/test_services.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_shell.py (renamed from novaclient/tests/v1_1/test_shell.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_usage.py (renamed from novaclient/tests/v1_1/test_usage.py)4
-rw-r--r--novaclient/tests/unit/v1_1/test_volumes.py (renamed from novaclient/tests/v1_1/test_volumes.py)4
-rw-r--r--novaclient/tests/unit/v1_1/testfile.txt (renamed from novaclient/tests/v1_1/testfile.txt)0
-rw-r--r--novaclient/tests/unit/v1_1/utils.py (renamed from novaclient/tests/v1_1/utils.py)0
79 files changed, 140 insertions, 140 deletions
diff --git a/novaclient/tests/fixture_data/__init__.py b/novaclient/tests/unit/__init__.py
index e69de29b..e69de29b 100644
--- a/novaclient/tests/fixture_data/__init__.py
+++ b/novaclient/tests/unit/__init__.py
diff --git a/novaclient/tests/fakes.py b/novaclient/tests/unit/fakes.py
index ef6b59b5..ef6b59b5 100644
--- a/novaclient/tests/fakes.py
+++ b/novaclient/tests/unit/fakes.py
diff --git a/novaclient/tests/v1_1/__init__.py b/novaclient/tests/unit/fixture_data/__init__.py
index e69de29b..e69de29b 100644
--- a/novaclient/tests/v1_1/__init__.py
+++ b/novaclient/tests/unit/fixture_data/__init__.py
diff --git a/novaclient/tests/fixture_data/agents.py b/novaclient/tests/unit/fixture_data/agents.py
index f1c2aed0..46a0bb67 100644
--- a/novaclient/tests/fixture_data/agents.py
+++ b/novaclient/tests/unit/fixture_data/agents.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/aggregates.py b/novaclient/tests/unit/fixture_data/aggregates.py
index 26f00d7a..ed743ed1 100644
--- a/novaclient/tests/fixture_data/aggregates.py
+++ b/novaclient/tests/unit/fixture_data/aggregates.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/availability_zones.py b/novaclient/tests/unit/fixture_data/availability_zones.py
index 008cea2a..36659d70 100644
--- a/novaclient/tests/fixture_data/availability_zones.py
+++ b/novaclient/tests/unit/fixture_data/availability_zones.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class V1(base.Fixture):
diff --git a/novaclient/tests/fixture_data/base.py b/novaclient/tests/unit/fixture_data/base.py
index 6a2e238b..6a2e238b 100644
--- a/novaclient/tests/fixture_data/base.py
+++ b/novaclient/tests/unit/fixture_data/base.py
diff --git a/novaclient/tests/fixture_data/certs.py b/novaclient/tests/unit/fixture_data/certs.py
index 243bb0ea..1dedaa4a 100644
--- a/novaclient/tests/fixture_data/certs.py
+++ b/novaclient/tests/unit/fixture_data/certs.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/client.py b/novaclient/tests/unit/fixture_data/client.py
index c6ddad3b..c6ddad3b 100644
--- a/novaclient/tests/fixture_data/client.py
+++ b/novaclient/tests/unit/fixture_data/client.py
diff --git a/novaclient/tests/fixture_data/cloudpipe.py b/novaclient/tests/unit/fixture_data/cloudpipe.py
index 9cb4efa8..abe59056 100644
--- a/novaclient/tests/fixture_data/cloudpipe.py
+++ b/novaclient/tests/unit/fixture_data/cloudpipe.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/fixedips.py b/novaclient/tests/unit/fixture_data/fixedips.py
index 71f18a4e..fb677e91 100644
--- a/novaclient/tests/fixture_data/fixedips.py
+++ b/novaclient/tests/unit/fixture_data/fixedips.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/floatingips.py b/novaclient/tests/unit/fixture_data/floatingips.py
index 4829a5a3..10772a79 100644
--- a/novaclient/tests/fixture_data/floatingips.py
+++ b/novaclient/tests/unit/fixture_data/floatingips.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class FloatingFixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/fping.py b/novaclient/tests/unit/fixture_data/fping.py
index 837db6da..6c6cd4f8 100644
--- a/novaclient/tests/fixture_data/fping.py
+++ b/novaclient/tests/unit/fixture_data/fping.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/hosts.py b/novaclient/tests/unit/fixture_data/hosts.py
index e7684f60..5c1ff60a 100644
--- a/novaclient/tests/fixture_data/hosts.py
+++ b/novaclient/tests/unit/fixture_data/hosts.py
@@ -13,7 +13,7 @@
from oslo.serialization import jsonutils
from six.moves.urllib import parse
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class BaseFixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/hypervisors.py b/novaclient/tests/unit/fixture_data/hypervisors.py
index 83a37d58..62952f08 100644
--- a/novaclient/tests/fixture_data/hypervisors.py
+++ b/novaclient/tests/unit/fixture_data/hypervisors.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class V1(base.Fixture):
diff --git a/novaclient/tests/fixture_data/images.py b/novaclient/tests/unit/fixture_data/images.py
index 9c9ef10f..02f35966 100644
--- a/novaclient/tests/fixture_data/images.py
+++ b/novaclient/tests/unit/fixture_data/images.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class V1(base.Fixture):
diff --git a/novaclient/tests/fixture_data/keypairs.py b/novaclient/tests/unit/fixture_data/keypairs.py
index 9017d1cf..9314c58a 100644
--- a/novaclient/tests/fixture_data/keypairs.py
+++ b/novaclient/tests/unit/fixture_data/keypairs.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class V1(base.Fixture):
diff --git a/novaclient/tests/fixture_data/limits.py b/novaclient/tests/unit/fixture_data/limits.py
index 0b9488d3..55d324d9 100644
--- a/novaclient/tests/fixture_data/limits.py
+++ b/novaclient/tests/unit/fixture_data/limits.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/networks.py b/novaclient/tests/unit/fixture_data/networks.py
index 023dce42..9ef692c3 100644
--- a/novaclient/tests/fixture_data/networks.py
+++ b/novaclient/tests/unit/fixture_data/networks.py
@@ -12,7 +12,7 @@
from oslo.serialization import jsonutils
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/quotas.py b/novaclient/tests/unit/fixture_data/quotas.py
index 3972d20f..83f448f4 100644
--- a/novaclient/tests/fixture_data/quotas.py
+++ b/novaclient/tests/unit/fixture_data/quotas.py
@@ -10,7 +10,7 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class V1(base.Fixture):
diff --git a/novaclient/tests/fixture_data/security_group_rules.py b/novaclient/tests/unit/fixture_data/security_group_rules.py
index aab4c245..5f1d2fad 100644
--- a/novaclient/tests/fixture_data/security_group_rules.py
+++ b/novaclient/tests/unit/fixture_data/security_group_rules.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/security_groups.py b/novaclient/tests/unit/fixture_data/security_groups.py
index 9f2f96b7..ac5d182c 100644
--- a/novaclient/tests/fixture_data/security_groups.py
+++ b/novaclient/tests/unit/fixture_data/security_groups.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/fixture_data/server_groups.py b/novaclient/tests/unit/fixture_data/server_groups.py
index 6defc895..1fcfdea5 100644
--- a/novaclient/tests/fixture_data/server_groups.py
+++ b/novaclient/tests/unit/fixture_data/server_groups.py
@@ -12,7 +12,7 @@
from oslo.serialization import jsonutils
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit.fixture_data import base
class Fixture(base.Fixture):
diff --git a/novaclient/tests/idfake.pem b/novaclient/tests/unit/idfake.pem
index f7b44664..f7b44664 100644
--- a/novaclient/tests/idfake.pem
+++ b/novaclient/tests/unit/idfake.pem
diff --git a/novaclient/tests/test_auth_plugins.py b/novaclient/tests/unit/test_auth_plugins.py
index 33bf481b..992077d0 100644
--- a/novaclient/tests/test_auth_plugins.py
+++ b/novaclient/tests/unit/test_auth_plugins.py
@@ -27,7 +27,7 @@ except ImportError:
from novaclient import auth_plugin
from novaclient import exceptions
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
from novaclient.v1_1 import client
diff --git a/novaclient/tests/test_base.py b/novaclient/tests/unit/test_base.py
index fca5b72d..d3fc6c75 100644
--- a/novaclient/tests/test_base.py
+++ b/novaclient/tests/unit/test_base.py
@@ -13,8 +13,8 @@
from novaclient import base
from novaclient import exceptions
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import flavors
diff --git a/novaclient/tests/test_client.py b/novaclient/tests/unit/test_client.py
index 9b841c8a..f8161156 100644
--- a/novaclient/tests/test_client.py
+++ b/novaclient/tests/unit/test_client.py
@@ -23,7 +23,7 @@ import requests
import novaclient.client
import novaclient.extension
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
import novaclient.v1_1.client
diff --git a/novaclient/tests/test_discover.py b/novaclient/tests/unit/test_discover.py
index a4988249..f8414c66 100644
--- a/novaclient/tests/test_discover.py
+++ b/novaclient/tests/unit/test_discover.py
@@ -20,7 +20,7 @@ import mock
import pkg_resources
import novaclient.shell
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
class DiscoverTest(utils.TestCase):
diff --git a/novaclient/tests/test_http.py b/novaclient/tests/unit/test_http.py
index bd12ed82..671ab09d 100644
--- a/novaclient/tests/test_http.py
+++ b/novaclient/tests/unit/test_http.py
@@ -17,7 +17,7 @@ import six
from novaclient import client
from novaclient import exceptions
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
fake_response = utils.TestResponse({
diff --git a/novaclient/tests/test_service_catalog.py b/novaclient/tests/unit/test_service_catalog.py
index 6f6ff4f4..33be7779 100644
--- a/novaclient/tests/test_service_catalog.py
+++ b/novaclient/tests/unit/test_service_catalog.py
@@ -15,7 +15,7 @@ from keystoneclient import fixture
from novaclient import exceptions
from novaclient import service_catalog
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
SERVICE_CATALOG = fixture.V2Token()
diff --git a/novaclient/tests/test_shell.py b/novaclient/tests/unit/test_shell.py
index 4f4e464e..794e88a3 100644
--- a/novaclient/tests/test_shell.py
+++ b/novaclient/tests/unit/test_shell.py
@@ -26,7 +26,7 @@ from testtools import matchers
import novaclient.client
from novaclient import exceptions
import novaclient.shell
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
FAKE_ENV = {'OS_USERNAME': 'username',
'OS_PASSWORD': 'password',
diff --git a/novaclient/tests/test_utils.py b/novaclient/tests/unit/test_utils.py
index b0079ef3..fe045263 100644
--- a/novaclient/tests/test_utils.py
+++ b/novaclient/tests/unit/test_utils.py
@@ -18,7 +18,7 @@ import six
from novaclient import base
from novaclient import exceptions
-from novaclient.tests import utils as test_utils
+from novaclient.tests.unit import utils as test_utils
from novaclient import utils
UUID = '8e8ec658-c7b0-4243-bdf8-6f7f2952c0d0'
diff --git a/novaclient/tests/utils.py b/novaclient/tests/unit/utils.py
index ab1ddcd1..ab1ddcd1 100644
--- a/novaclient/tests/utils.py
+++ b/novaclient/tests/unit/utils.py
diff --git a/novaclient/tests/v1_1/contrib/__init__.py b/novaclient/tests/unit/v1_1/__init__.py
index e69de29b..e69de29b 100644
--- a/novaclient/tests/v1_1/contrib/__init__.py
+++ b/novaclient/tests/unit/v1_1/__init__.py
diff --git a/novaclient/tests/unit/v1_1/contrib/__init__.py b/novaclient/tests/unit/v1_1/contrib/__init__.py
new file mode 100644
index 00000000..e69de29b
--- /dev/null
+++ b/novaclient/tests/unit/v1_1/contrib/__init__.py
diff --git a/novaclient/tests/v1_1/contrib/fakes.py b/novaclient/tests/unit/v1_1/contrib/fakes.py
index 43c6e6de..e961ae10 100644
--- a/novaclient/tests/v1_1/contrib/fakes.py
+++ b/novaclient/tests/unit/v1_1/contrib/fakes.py
@@ -12,7 +12,7 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import client
diff --git a/novaclient/tests/v1_1/contrib/test_assisted_volume_snapshots.py b/novaclient/tests/unit/v1_1/contrib/test_assisted_volume_snapshots.py
index 426d6deb..37f584ce 100644
--- a/novaclient/tests/v1_1/contrib/test_assisted_volume_snapshots.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_assisted_volume_snapshots.py
@@ -17,8 +17,8 @@ Assisted volume snapshots - to be used by Cinder and not end users.
"""
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import assisted_volume_snapshots as assisted_snaps
diff --git a/novaclient/tests/v1_1/contrib/test_baremetal.py b/novaclient/tests/unit/v1_1/contrib/test_baremetal.py
index 172d8b27..1866eea6 100644
--- a/novaclient/tests/v1_1/contrib/test_baremetal.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_baremetal.py
@@ -15,8 +15,8 @@
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import baremetal
diff --git a/novaclient/tests/v1_1/contrib/test_cells.py b/novaclient/tests/unit/v1_1/contrib/test_cells.py
index 187fab84..ccdcd375 100644
--- a/novaclient/tests/v1_1/contrib/test_cells.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_cells.py
@@ -14,8 +14,8 @@
# under the License.
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import cells
diff --git a/novaclient/tests/v1_1/contrib/test_instance_actions.py b/novaclient/tests/unit/v1_1/contrib/test_instance_actions.py
index 36478197..66dbb418 100644
--- a/novaclient/tests/v1_1/contrib/test_instance_actions.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_instance_actions.py
@@ -14,8 +14,8 @@
# under the License.
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import instance_action
diff --git a/novaclient/tests/v1_1/contrib/test_list_extensions.py b/novaclient/tests/unit/v1_1/contrib/test_list_extensions.py
index 77b6a342..dfb742eb 100644
--- a/novaclient/tests/v1_1/contrib/test_list_extensions.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_list_extensions.py
@@ -12,8 +12,8 @@
# under the License.
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1.contrib import list_extensions
diff --git a/novaclient/tests/v1_1/contrib/test_migrations.py b/novaclient/tests/unit/v1_1/contrib/test_migrations.py
index 5337502a..5fe5c8f0 100644
--- a/novaclient/tests/v1_1/contrib/test_migrations.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_migrations.py
@@ -11,8 +11,8 @@
# under the License.
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1.contrib import migrations
extensions = [
diff --git a/novaclient/tests/v1_1/contrib/test_server_external_events.py b/novaclient/tests/unit/v1_1/contrib/test_server_external_events.py
index c92ba34e..a933ad89 100644
--- a/novaclient/tests/v1_1/contrib/test_server_external_events.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_server_external_events.py
@@ -17,8 +17,8 @@ External event triggering for servers, not to be used by users.
"""
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import server_external_events as ext_events
diff --git a/novaclient/tests/v1_1/contrib/test_tenant_networks.py b/novaclient/tests/unit/v1_1/contrib/test_tenant_networks.py
index 1289928b..a1a76cee 100644
--- a/novaclient/tests/v1_1/contrib/test_tenant_networks.py
+++ b/novaclient/tests/unit/v1_1/contrib/test_tenant_networks.py
@@ -14,8 +14,8 @@
# under the License.
from novaclient import extension
-from novaclient.tests import utils
-from novaclient.tests.v1_1.contrib import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1.contrib import fakes
from novaclient.v1_1.contrib import tenant_networks
diff --git a/novaclient/tests/v1_1/test_agents.py b/novaclient/tests/unit/v1_1/test_agents.py
index dbe7af49..a269b322 100644
--- a/novaclient/tests/v1_1/test_agents.py
+++ b/novaclient/tests/unit/v1_1/test_agents.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import agents as data
-from novaclient.tests.fixture_data import client
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import agents as data
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit import utils
from novaclient.v1_1 import agents
diff --git a/novaclient/tests/v1_1/test_aggregates.py b/novaclient/tests/unit/v1_1/test_aggregates.py
index 6e7bd44e..40cc7d92 100644
--- a/novaclient/tests/v1_1/test_aggregates.py
+++ b/novaclient/tests/unit/v1_1/test_aggregates.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import aggregates as data
-from novaclient.tests.fixture_data import client
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import aggregates as data
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit import utils
from novaclient.v1_1 import aggregates
diff --git a/novaclient/tests/v1_1/test_auth.py b/novaclient/tests/unit/v1_1/test_auth.py
index 97e40279..65715e54 100644
--- a/novaclient/tests/v1_1/test_auth.py
+++ b/novaclient/tests/unit/v1_1/test_auth.py
@@ -19,7 +19,7 @@ import mock
import requests
from novaclient import exceptions
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
from novaclient.v1_1 import client
diff --git a/novaclient/tests/v1_1/test_availability_zone.py b/novaclient/tests/unit/v1_1/test_availability_zone.py
index be0623ad..fda4764a 100644
--- a/novaclient/tests/v1_1/test_availability_zone.py
+++ b/novaclient/tests/unit/v1_1/test_availability_zone.py
@@ -16,9 +16,9 @@
import six
-from novaclient.tests.fixture_data import availability_zones as data
-from novaclient.tests.fixture_data import client
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import availability_zones as data
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit import utils
from novaclient.v1_1 import availability_zones
diff --git a/novaclient/tests/v1_1/test_certs.py b/novaclient/tests/unit/v1_1/test_certs.py
index 0a568d58..39eac06f 100644
--- a/novaclient/tests/v1_1/test_certs.py
+++ b/novaclient/tests/unit/v1_1/test_certs.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import certs as data
-from novaclient.tests.fixture_data import client
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import certs as data
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit import utils
from novaclient.v1_1 import certs
diff --git a/novaclient/tests/v1_1/test_client.py b/novaclient/tests/unit/v1_1/test_client.py
index fa0ed3af..fbc98f7c 100644
--- a/novaclient/tests/v1_1/test_client.py
+++ b/novaclient/tests/unit/v1_1/test_client.py
@@ -14,7 +14,7 @@ import uuid
from keystoneclient import session
-from novaclient.tests import utils
+from novaclient.tests.unit import utils
from novaclient.v1_1 import client
diff --git a/novaclient/tests/v1_1/test_cloudpipe.py b/novaclient/tests/unit/v1_1/test_cloudpipe.py
index 0a319085..0a40db68 100644
--- a/novaclient/tests/v1_1/test_cloudpipe.py
+++ b/novaclient/tests/unit/v1_1/test_cloudpipe.py
@@ -13,9 +13,9 @@
import six
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import cloudpipe as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import cloudpipe as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import cloudpipe
diff --git a/novaclient/tests/v1_1/test_fixed_ips.py b/novaclient/tests/unit/v1_1/test_fixed_ips.py
index 5cfecf33..02ba39b6 100644
--- a/novaclient/tests/v1_1/test_fixed_ips.py
+++ b/novaclient/tests/unit/v1_1/test_fixed_ips.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import fixedips as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import fixedips as data
+from novaclient.tests.unit import utils
class FixedIpsTest(utils.FixturedTestCase):
diff --git a/novaclient/tests/v1_1/test_flavor_access.py b/novaclient/tests/unit/v1_1/test_flavor_access.py
index b85f838e..08677ad4 100644
--- a/novaclient/tests/v1_1/test_flavor_access.py
+++ b/novaclient/tests/unit/v1_1/test_flavor_access.py
@@ -13,8 +13,8 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import flavor_access
diff --git a/novaclient/tests/v1_1/test_flavors.py b/novaclient/tests/unit/v1_1/test_flavors.py
index a69db858..90f7eb1d 100644
--- a/novaclient/tests/v1_1/test_flavors.py
+++ b/novaclient/tests/unit/v1_1/test_flavors.py
@@ -16,8 +16,8 @@
import mock
from novaclient import exceptions
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import flavors
diff --git a/novaclient/tests/v1_1/test_floating_ip_dns.py b/novaclient/tests/unit/v1_1/test_floating_ip_dns.py
index 2ded1725..36f900ce 100644
--- a/novaclient/tests/v1_1/test_floating_ip_dns.py
+++ b/novaclient/tests/unit/v1_1/test_floating_ip_dns.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import floatingips as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import floatingips as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import floating_ip_dns
diff --git a/novaclient/tests/v1_1/test_floating_ip_pools.py b/novaclient/tests/unit/v1_1/test_floating_ip_pools.py
index f2d0c8fd..55470dae 100644
--- a/novaclient/tests/v1_1/test_floating_ip_pools.py
+++ b/novaclient/tests/unit/v1_1/test_floating_ip_pools.py
@@ -14,9 +14,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import floatingips as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import floatingips as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import floating_ip_pools
diff --git a/novaclient/tests/v1_1/test_floating_ips.py b/novaclient/tests/unit/v1_1/test_floating_ips.py
index 93cc733b..7deb2b65 100644
--- a/novaclient/tests/v1_1/test_floating_ips.py
+++ b/novaclient/tests/unit/v1_1/test_floating_ips.py
@@ -14,9 +14,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import floatingips as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import floatingips as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import floating_ips
diff --git a/novaclient/tests/v1_1/test_floating_ips_bulk.py b/novaclient/tests/unit/v1_1/test_floating_ips_bulk.py
index ac21c1cb..c53e453d 100644
--- a/novaclient/tests/v1_1/test_floating_ips_bulk.py
+++ b/novaclient/tests/unit/v1_1/test_floating_ips_bulk.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import floatingips as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import floatingips as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import floating_ips_bulk
diff --git a/novaclient/tests/v1_1/test_fping.py b/novaclient/tests/unit/v1_1/test_fping.py
index 5a3fb640..7fe54bc8 100644
--- a/novaclient/tests/v1_1/test_fping.py
+++ b/novaclient/tests/unit/v1_1/test_fping.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import fping as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import fping as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import fping
diff --git a/novaclient/tests/v1_1/test_hosts.py b/novaclient/tests/unit/v1_1/test_hosts.py
index 8fcdf5a7..b51ab071 100644
--- a/novaclient/tests/v1_1/test_hosts.py
+++ b/novaclient/tests/unit/v1_1/test_hosts.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import hosts as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import hosts as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import hosts
diff --git a/novaclient/tests/v1_1/test_hypervisors.py b/novaclient/tests/unit/v1_1/test_hypervisors.py
index 1a621201..b297c124 100644
--- a/novaclient/tests/v1_1/test_hypervisors.py
+++ b/novaclient/tests/unit/v1_1/test_hypervisors.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import hypervisors as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import hypervisors as data
+from novaclient.tests.unit import utils
class HypervisorsTest(utils.FixturedTestCase):
diff --git a/novaclient/tests/v1_1/test_images.py b/novaclient/tests/unit/v1_1/test_images.py
index e5fcfca9..4f7d5537 100644
--- a/novaclient/tests/v1_1/test_images.py
+++ b/novaclient/tests/unit/v1_1/test_images.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import images as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import images as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import images
diff --git a/novaclient/tests/v1_1/test_keypairs.py b/novaclient/tests/unit/v1_1/test_keypairs.py
index 9e8e63fd..a5cf2591 100644
--- a/novaclient/tests/v1_1/test_keypairs.py
+++ b/novaclient/tests/unit/v1_1/test_keypairs.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import keypairs as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import keypairs as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import keypairs
diff --git a/novaclient/tests/v1_1/test_limits.py b/novaclient/tests/unit/v1_1/test_limits.py
index 212be454..598c38a0 100644
--- a/novaclient/tests/v1_1/test_limits.py
+++ b/novaclient/tests/unit/v1_1/test_limits.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import limits as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import limits as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import limits
diff --git a/novaclient/tests/v1_1/test_networks.py b/novaclient/tests/unit/v1_1/test_networks.py
index 1fbd112c..4e57c2b6 100644
--- a/novaclient/tests/v1_1/test_networks.py
+++ b/novaclient/tests/unit/v1_1/test_networks.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import networks as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import networks as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import networks
diff --git a/novaclient/tests/v1_1/test_quota_classes.py b/novaclient/tests/unit/v1_1/test_quota_classes.py
index 338549bf..8e651bae 100644
--- a/novaclient/tests/v1_1/test_quota_classes.py
+++ b/novaclient/tests/unit/v1_1/test_quota_classes.py
@@ -13,8 +13,8 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
cs = fakes.FakeClient()
diff --git a/novaclient/tests/v1_1/test_quotas.py b/novaclient/tests/unit/v1_1/test_quotas.py
index 8ff0d596..43f8ce1d 100644
--- a/novaclient/tests/v1_1/test_quotas.py
+++ b/novaclient/tests/unit/v1_1/test_quotas.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import quotas as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import quotas as data
+from novaclient.tests.unit import utils
class QuotaSetsTest(utils.FixturedTestCase):
diff --git a/novaclient/tests/v1_1/test_security_group_rules.py b/novaclient/tests/unit/v1_1/test_security_group_rules.py
index 7de882f9..af5b81d4 100644
--- a/novaclient/tests/v1_1/test_security_group_rules.py
+++ b/novaclient/tests/unit/v1_1/test_security_group_rules.py
@@ -12,9 +12,9 @@
# under the License.
from novaclient import exceptions
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import security_group_rules as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import security_group_rules as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import security_group_rules
diff --git a/novaclient/tests/v1_1/test_security_groups.py b/novaclient/tests/unit/v1_1/test_security_groups.py
index f5b771af..91c9ef3f 100644
--- a/novaclient/tests/v1_1/test_security_groups.py
+++ b/novaclient/tests/unit/v1_1/test_security_groups.py
@@ -11,9 +11,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import security_groups as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import security_groups as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import security_groups
diff --git a/novaclient/tests/v1_1/test_server_groups.py b/novaclient/tests/unit/v1_1/test_server_groups.py
index f7a5a214..eecd71d4 100644
--- a/novaclient/tests/v1_1/test_server_groups.py
+++ b/novaclient/tests/unit/v1_1/test_server_groups.py
@@ -13,9 +13,9 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import server_groups as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import server_groups as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import server_groups
diff --git a/novaclient/tests/v1_1/test_services.py b/novaclient/tests/unit/v1_1/test_services.py
index acd25152..61cbd67f 100644
--- a/novaclient/tests/v1_1/test_services.py
+++ b/novaclient/tests/unit/v1_1/test_services.py
@@ -13,8 +13,8 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import services
diff --git a/novaclient/tests/v1_1/test_shell.py b/novaclient/tests/unit/v1_1/test_shell.py
index c1b5e1af..ccece801 100644
--- a/novaclient/tests/v1_1/test_shell.py
+++ b/novaclient/tests/unit/v1_1/test_shell.py
@@ -29,8 +29,8 @@ from six.moves import builtins
import novaclient.client
from novaclient import exceptions
import novaclient.shell
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
import novaclient.v1_1.shell
diff --git a/novaclient/tests/v1_1/test_usage.py b/novaclient/tests/unit/v1_1/test_usage.py
index fe0f1e94..2f52706d 100644
--- a/novaclient/tests/v1_1/test_usage.py
+++ b/novaclient/tests/unit/v1_1/test_usage.py
@@ -13,8 +13,8 @@
import datetime
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import usage
diff --git a/novaclient/tests/v1_1/test_volumes.py b/novaclient/tests/unit/v1_1/test_volumes.py
index 61a21534..432b8053 100644
--- a/novaclient/tests/v1_1/test_volumes.py
+++ b/novaclient/tests/unit/v1_1/test_volumes.py
@@ -13,8 +13,8 @@
# License for the specific language governing permissions and limitations
# under the License.
-from novaclient.tests import utils
-from novaclient.tests.v1_1 import fakes
+from novaclient.tests.unit import utils
+from novaclient.tests.unit.v1_1 import fakes
from novaclient.v1_1 import volumes
diff --git a/novaclient/tests/v1_1/testfile.txt b/novaclient/tests/unit/v1_1/testfile.txt
index e4e860f3..e4e860f3 100644
--- a/novaclient/tests/v1_1/testfile.txt
+++ b/novaclient/tests/unit/v1_1/testfile.txt
diff --git a/novaclient/tests/v1_1/utils.py b/novaclient/tests/unit/v1_1/utils.py
index d28392f9..d28392f9 100644
--- a/novaclient/tests/v1_1/utils.py
+++ b/novaclient/tests/unit/v1_1/utils.py
diff --git a/novaclient/tests/fixture_data/servers.py b/novaclient/tests/unit/fixture_data/servers.py
index c728f2ff..6e3dd46b 100644
--- a/novaclient/tests/fixture_data/servers.py
+++ b/novaclient/tests/unit/fixture_data/servers.py
@@ -12,8 +12,8 @@
from oslo.serialization import jsonutils
-from novaclient.tests import fakes
-from novaclient.tests.fixture_data import base
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit.fixture_data import base
class Base(base.Fixture):
@@ -336,7 +336,7 @@ class V1(Base):
#
# Clear password: FooBar123
#
# RSA Private Key: novaclient/tests/idfake.pem
#
# Encrypted password
# OIuEuQttO8Rk93BcKlwHQsziDAnkAm/V6V8VPToA8ZeUaUBWwS0gwo2K6Y61Z96r
@@ -336,7 +336,7 @@ class V1(Base):
# Clear password: FooBar123
#
- # RSA Private Key: novaclient/tests/idfake.pem
+ # RSA Private Key: novaclient/tests/unit/idfake.pem
#
# Encrypted password
diff --git a/novaclient/tests/v1_1/fakes.py b/novaclient/tests/unit/v1_1/fakes.py
index 92c92389..6d97374f 100644
--- a/novaclient/tests/v1_1/fakes.py
+++ b/novaclient/tests/unit/v1_1/fakes.py
@@ -22,8 +22,8 @@ from six.moves.urllib import parse
from novaclient import client as base_client
from novaclient import exceptions
-from novaclient.tests import fakes
-from novaclient.tests import utils
+from novaclient.tests.unit import fakes
+from novaclient.tests.unit import utils
from novaclient.v1_1 import client
@@ -515,7 +515,7 @@ class FakeHTTPClient(base_client.HTTPClient):
#
# Clear password: FooBar123
#
# RSA Private Key: novaclient/tests/idfake.pem
#
# Encrypted password
# OIuEuQttO8Rk93BcKlwHQsziDAnkAm/V6V8VPToA8ZeUaUBWwS0gwo2K6Y61Z96r
@@ -515,7 +515,7 @@ class FakeHTTPClient(base_client.HTTPClient):
# Clear password: FooBar123
#
- # RSA Private Key: novaclient/tests/idfake.pem
+ # RSA Private Key: novaclient/tests/unit/idfake.pem
#
# Encrypted password
diff --git a/novaclient/tests/v1_1/test_servers.py b/novaclient/tests/unit/v1_1/test_servers.py
index c4037e1b..214f394e 100644
--- a/novaclient/tests/v1_1/test_servers.py
+++ b/novaclient/tests/unit/v1_1/test_servers.py
@@ -17,10 +17,10 @@ from oslo.serialization import jsonutils
import six
from novaclient import exceptions
-from novaclient.tests.fixture_data import client
-from novaclient.tests.fixture_data import floatingips
-from novaclient.tests.fixture_data import servers as data
-from novaclient.tests import utils
+from novaclient.tests.unit.fixture_data import client
+from novaclient.tests.unit.fixture_data import floatingips
+from novaclient.tests.unit.fixture_data import servers as data
+from novaclient.tests.unit import utils
from novaclient.v1_1 import servers
@@ -525,7 +525,7 @@ class ServersTest(utils.FixturedTestCase):
#
# Clear password: FooBar123
#
# RSA Private Key: novaclient/tests/idfake.pem
#
# Encrypted password
# OIuEuQttO8Rk93BcKlwHQsziDAnkAm/V6V8VPToA8ZeUaUBWwS0gwo2K6Y61Z96r
@@ -538,7 +538,7 @@ class ServersTest(utils.FixturedTestCase):
def test_get_password(self):
s = self.cs.servers.get(1234)
self.assertEqual(b'FooBar123',
- s.get_password('novaclient/tests/idfake.pem'))
+ s.get_password('novaclient/tests/unit/idfake.pem'))
self.assert_called('GET', '/servers/1234/os-server-password')
def test_get_password_without_key(self):
@@ -525,7 +525,7 @@ class ServersTest(utils.FixturedTestCase):
# Clear password: FooBar123
#
- # RSA Private Key: novaclient/tests/idfake.pem
+ # RSA Private Key: novaclient/tests/unit/idfake.pem
#
# Encrypted password